#ifndef	AUTH_DONGLE_API_H
#define	AUTH_DONGLE_API_H
/*
 * Written by Oron Peled <oron@actcom.co.il>
 * Copyright (C) 2013, Xorcom
 *
 * All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

#ifdef __cplusplus
extern "C"
{
#endif /* __cplusplus */

#include <xtalk/xusb.h>
#include <xtalk/proto_sync.h>

#define	SERIAL_BLOCK_LEN	64

struct auth_dongle;

/*
 * This is a combination of:
 *    - auth_dongle_find()
 *    - auth_dongle_timeout()
 *    - auth_dongle_retries()
 *    - auth_dongle_proto_query()
 */
struct auth_dongle *auth_dongle_setup(xusb_filter_t filter, char *devpath, int retries, int timeout);

/* High-level API */
void auth_dongle_cleanup(struct auth_dongle *auth_dongle);
const char *auth_dongle_read_serial(struct auth_dongle *auth_dongle);

/* Mid-level API */
struct auth_dongle *auth_dongle_find(xusb_filter_t filter, char *devpath);
int auth_dongle_proto_query(struct auth_dongle *auth_dongle);
int auth_dongle_proto_verify(struct auth_dongle *auth_dongle);
struct auth_dongle *new_auth_dongle(struct xusb_device *xusb_device);
void delete_auth_dongle(struct auth_dongle *auth_dongle);
struct xusb_device *xusb_of_auth_dongle(struct auth_dongle *auth_dongle);

/* Low-level API */
int auth_dongle_timeout(struct auth_dongle *auth_dongle, int timeout);
int auth_dongle_retries(struct auth_dongle *auth_dongle, int retries);
int auth_dongle_read_block(struct auth_dongle *auth_dongle, char data[],
	off_t offset, size_t len, int null_stop);
int auth_dongle_write_block(struct auth_dongle *auth_dongle, char data[],
	off_t offset, size_t len);
int auth_dongle_fw_version(struct auth_dongle *auth_dongle, uint8_t data[], int *maxlen);

#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif	/* AUTH_DONGLE_API_H */
